@@ -4,11 +4,11 @@ import collections
 import itertools
 import sys
 
-from pytype import abstract
-from pytype import abstract_utils
-from pytype import class_mixin
-from pytype import mixin
 from pytype import utils
+from pytype.abstract import abstract
+from pytype.abstract import abstract_utils
+from pytype.abstract import class_mixin
+from pytype.abstract import mixin
 from pytype.overlays import typing_overlay
 
 
