@@ -2,14 +2,14 @@
 import logging
 from typing import Optional
 
-from pytype import abstract
-from pytype import abstract_utils
-from pytype import class_mixin
-from pytype import function
-from pytype import mixin
 from pytype import overlay
 from pytype import special_builtins
 from pytype import utils
+from pytype.abstract import abstract
+from pytype.abstract import abstract_utils
+from pytype.abstract import class_mixin
+from pytype.abstract import function
+from pytype.abstract import mixin
 from pytype.typegraph import cfg
 
 log = logging.getLogger(__name__)
@@ -208,7 +208,11 @@ class AbstractAttributeHandler(utils.ContextWeakrefMixin):
     """Get an attribute from a module."""
     assert isinstance(module, abstract.Module)
 
-    node, var = self._get_instance_attribute(node, module, name, valself)
+    try:
+      node, var = self._get_instance_attribute(node, module, name, valself)
+    except abstract_utils.ModuleLoadError:
+      var = None
+
     if not self._should_look_for_submodule(module, var):
       return node, var
 
