@@ -3,16 +3,16 @@
 import logging
 import types
 
-from pytype import abstract
-from pytype import abstract_utils
 from pytype import blocks
-from pytype import class_mixin
 from pytype import datatypes
-from pytype import function
 from pytype import overlay_dict
-from pytype import mixin
 from pytype import special_builtins
 from pytype import utils
+from pytype.abstract import abstract
+from pytype.abstract import abstract_utils
+from pytype.abstract import class_mixin
+from pytype.abstract import function
+from pytype.abstract import mixin
 from pytype.overlays import attr_overlay
 from pytype.overlays import typing_overlay
 from pytype.pyc import loadmarshal
@@ -532,6 +532,8 @@ class Converter(utils.ContextWeakrefMixin):
     return self._resolved_late_types[late_type.name]
 
   def _create_module(self, ast):
+    if not ast:
+      raise abstract_utils.ModuleLoadError()
     data = (ast.constants + ast.type_params + ast.classes +
             ast.functions + ast.aliases)
     members = {val.name.rsplit(".")[-1]: val for val in data}
