@@ -1,12 +1,12 @@
 """Tests for convert.py."""
 
-from pytype import abstract
-from pytype import abstract_utils
 from pytype import config
 from pytype import context
 from pytype import errors
 from pytype import file_utils
 from pytype import load_pytd
+from pytype.abstract import abstract
+from pytype.abstract import abstract_utils
 from pytype.pytd import pytd
 from pytype.pytd import pytd_utils
 from pytype.tests import test_base
