@@ -3,13 +3,13 @@ import collections
 import contextlib
 import logging
 
-from pytype import abstract
-from pytype import abstract_utils
-from pytype import class_mixin
 from pytype import datatypes
-from pytype import function
 from pytype import special_builtins
 from pytype import utils
+from pytype.abstract import abstract
+from pytype.abstract import abstract_utils
+from pytype.abstract import class_mixin
+from pytype.abstract import function
 from pytype.overlays import dataclass_overlay
 from pytype.overlays import typing_overlay
 from pytype.pytd import pep484
