@@ -4,13 +4,13 @@ import enum
 import logging
 from typing import Any, ClassVar, Dict, Optional, Tuple, Union
 
-from pytype import abstract
-from pytype import abstract_utils
-from pytype import class_mixin
-from pytype import function
-from pytype import mixin
 from pytype import overlay
 from pytype import overlay_utils
+from pytype.abstract import abstract
+from pytype.abstract import abstract_utils
+from pytype.abstract import class_mixin
+from pytype.abstract import function
+from pytype.abstract import mixin
 from pytype.overlays import classgen
 
 log = logging.getLogger(__name__)
