@@ -6,7 +6,7 @@ from pytype.overlays import typing_overlay
 class TypingExtensionsOverlay(overlay.Overlay):
   """A custom overlay for the 'typing_extensions' module."""
 
-  def __init__(self, vm):
+  def __init__(self, ctx):
     member_map = {
         "Annotated": typing_overlay.typing_overlay["Annotated"],
         "final": typing_overlay.typing_overlay["final"],
@@ -15,18 +15,18 @@ class TypingExtensionsOverlay(overlay.Overlay):
         "runtime": build_runtime,  # alias for runtime_checkable
         "TypedDict": typing_overlay.typing_overlay["TypedDict"],
     }
-    ast = vm.loader.import_name("typing_extensions")
+    ast = ctx.loader.import_name("typing_extensions")
     for pyval in ast.aliases + ast.classes + ast.constants + ast.functions:
       # Any public typing_extensions members that are not explicitly implemented
       # are unsupported.
       _, name = pyval.name.rsplit(".", 1)
       if name.startswith("_"):
         continue
-      if f"typing.{name}" not in vm.loader.typing:
+      if f"typing.{name}" not in ctx.loader.typing:
         if name not in member_map:
           member_map[name] = overlay.build(
               name, typing_overlay.not_supported_yet)
-    super().__init__(vm, "typing_extensions", member_map, ast)
+    super().__init__(ctx, "typing_extensions", member_map, ast)
 
   def _convert_member(self, member, subst=None):
     var = super()._convert_member(member, subst)
@@ -39,9 +39,9 @@ class TypingExtensionsOverlay(overlay.Overlay):
     return var
 
 
-def build_protocol(vm):
-  return vm.convert.name_to_value("typing.Protocol")
+def build_protocol(ctx):
+  return ctx.convert.name_to_value("typing.Protocol")
 
 
-def build_runtime(vm):
-  return vm.convert.name_to_value("typing.runtime_checkable")
+def build_runtime(ctx):
+  return ctx.convert.name_to_value("typing.runtime_checkable")
