@@ -1,10 +1,10 @@
 """Custom implementations of builtin types."""
 
-from pytype import abstract
-from pytype import abstract_utils
-from pytype import class_mixin
-from pytype import function
-from pytype import mixin
+from pytype.abstract import abstract
+from pytype.abstract import abstract_utils
+from pytype.abstract import class_mixin
+from pytype.abstract import function
+from pytype.abstract import mixin
 
 
 class TypeNew(abstract.PyTDFunction):
