@@ -61,14 +61,14 @@ ITEMS = {
 
 # The missing fields will be filled in by generate_sample_config_or_die.
 _PYTYPE_SINGLE_ITEMS = {
-    'attribute_variable_annotations': Item(
-        None, 'True', ArgInfo('--attribute-variable-annotations', None), None),
     'bind_properties': Item(
         None, 'False', ArgInfo('--bind-properties', None), None),
     'preserve_union_macros': Item(
-        None, 'False', ArgInfo('--preserve-union-macros', None), None),
+        None, 'True', ArgInfo('--preserve-union-macros', None), None),
     'use_enum_overlay': Item(
         None, 'False', ArgInfo('--use-enum-overlay', None), None),
+    'allow_recursive_types': Item(
+        None, 'False', ArgInfo('--use-recursive-types', None), None),
     'disable': Item(
         None, 'pyi-error', ArgInfo('--disable', ','.join),
         'Comma or space separated list of error names to ignore.'),
